Class: Google::Cloud::BinaryAuthorization::V1::AttestorPublicKey
- Inherits:
-
Object
- Object
- Google::Cloud::BinaryAuthorization::V1::AttestorPublicKey
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/binaryauthorization/v1/resources.rb
Overview
An [attestor public key][google.cloud.binaryauthorization.v1.AttestorPublicKey] that will be used to verify attestations signed by this attestor.
Instance Attribute Summary collapse
-
#ascii_armored_pgp_public_key ⇒ ::String
ASCII-armored representation of a PGP public key, as the entire output by the command
gpg --export --armor foo@example.com(either LF or CRLF line endings). -
#comment ⇒ ::String
Optional.
-
#id ⇒ ::String
The ID of this public key.
-
#pkix_public_key ⇒ ::Google::Cloud::BinaryAuthorization::V1::PkixPublicKey
A raw PKIX SubjectPublicKeyInfo format public key.
Instance Attribute Details
#ascii_armored_pgp_public_key ⇒ ::String
Returns ASCII-armored representation of a PGP public key, as the entire output by
the command gpg --export --armor foo@example.com (either LF or CRLF
line endings).
When using this field, id should be left blank. The Binary
Authorization API handlers will calculate the ID and fill it in
automatically. Binary Authorization computes this ID as the OpenPGP
RFC4880 V4 fingerprint, represented as upper-case hex. If id is
provided by the caller, it will be overwritten by the API-calculated ID.
Note: The following fields are mutually exclusive: ascii_armored_pgp_public_key, pkix_public_key. If a field in that set is populated, all other fields in the set will automatically be cleared.
421 422 423 424 |
# File 'proto_docs/google/cloud/binaryauthorization/v1/resources.rb', line 421 class AttestorPublicKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#comment ⇒ ::String
Returns Optional. A descriptive comment. This field may be updated.
421 422 423 424 |
# File 'proto_docs/google/cloud/binaryauthorization/v1/resources.rb', line 421 class AttestorPublicKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#id ⇒ ::String
Returns The ID of this public key.
Signatures verified by Binary Authorization must include the ID of the
public key that can be used to verify them, and that ID must match the
contents of this field exactly. Additional restrictions on this field can
be imposed based on which public key type is encapsulated. See the
documentation on public_key cases below for details.
421 422 423 424 |
# File 'proto_docs/google/cloud/binaryauthorization/v1/resources.rb', line 421 class AttestorPublicKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pkix_public_key ⇒ ::Google::Cloud::BinaryAuthorization::V1::PkixPublicKey
Returns A raw PKIX SubjectPublicKeyInfo format public key.
NOTE: id may be explicitly provided by the caller when using this
type of public key, but it MUST be a valid RFC3986 URI. If id is left
blank, a default one will be computed based on the digest of the DER
encoding of the public key.
Note: The following fields are mutually exclusive: pkix_public_key, ascii_armored_pgp_public_key. If a field in that set is populated, all other fields in the set will automatically be cleared.
421 422 423 424 |
# File 'proto_docs/google/cloud/binaryauthorization/v1/resources.rb', line 421 class AttestorPublicKey include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |