Class: Google::Cloud::BinaryAuthorization::V1::BinauthzManagementService::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::BinaryAuthorization::V1::BinauthzManagementService::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb
Overview
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client
readonly
Get the associated client for mix-in of the IAMPolicy.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the BinauthzManagementService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the BinauthzManagementService Client instance.
- #create_attestor(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor
-
#delete_attestor(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes an attestor.
-
#get_attestor(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor
Gets an attestor.
- #get_policy(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1::Policy
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new BinauthzManagementService REST client object.
-
#list_attestors(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1::Attestor>
Lists attestors.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#universe_domain ⇒ String
The effective universe domain.
-
#update_attestor(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor
Updates an attestor.
- #update_policy(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1::Policy
Methods included from Paths
#attestor_path, #policy_path, #project_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new BinauthzManagementService REST client object.
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 165 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @binauthz_management_service_stub = ::Google::Cloud::BinaryAuthorization::V1::BinauthzManagementService::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @binauthz_management_service_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @iam_policy_client = Google::Iam::V1::IAMPolicy::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @binauthz_management_service_stub.endpoint config.universe_domain = @binauthz_management_service_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @binauthz_management_service_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#iam_policy_client ⇒ Google::Iam::V1::IAMPolicy::Rest::Client (readonly)
Get the associated client for mix-in of the IAMPolicy.
221 222 223 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 221 def iam_policy_client @iam_policy_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the BinauthzManagementService Client class.
See Configuration for a description of the configuration fields.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 71 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "BinaryAuthorization", "V1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.get_policy.timeout = 600.0 default_config.rpcs.get_policy.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.update_policy.timeout = 600.0 default_config.rpcs.update_policy.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.create_attestor.timeout = 600.0 default_config.rpcs.get_attestor.timeout = 600.0 default_config.rpcs.get_attestor.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.update_attestor.timeout = 600.0 default_config.rpcs.update_attestor.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.list_attestors.timeout = 600.0 default_config.rpcs.list_attestors.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.delete_attestor.timeout = 600.0 default_config.rpcs.delete_attestor.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the BinauthzManagementService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
135 136 137 138 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 135 def configure yield @config if block_given? @config end |
#create_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor #create_attestor(parent: nil, attestor_id: nil, attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 467 def create_attestor request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1::CreateAttestorRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_attestor..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_attestor.timeout, metadata: , retry_policy: @config.rpcs.create_attestor.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.create_attestor request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_attestor(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_attestor(name: nil) ⇒ ::Google::Protobuf::Empty
810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 810 def delete_attestor request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1::DeleteAttestorRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_attestor..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_attestor.timeout, metadata: , retry_policy: @config.rpcs.delete_attestor.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.delete_attestor request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor #get_attestor(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 549 def get_attestor request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1::GetAttestorRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_attestor..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_attestor.timeout, metadata: , retry_policy: @config.rpcs.get_attestor.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.get_attestor request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Policy #get_policy(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Policy
A policy specifies the attestors that must attest to a container image, before the project is allowed to deploy that image. There is at most one policy per project. All image admission requests are permitted if a project has no policy.
Gets the policy for this project. Returns a default policy if the project does not have one.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 288 def get_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1::GetPolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_policy..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_policy.timeout, metadata: , retry_policy: @config.rpcs.get_policy.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.get_policy request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_attestors(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1::Attestor> #list_attestors(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1::Attestor>
Lists attestors.
Returns INVALID_ARGUMENT if the project does not exist.
726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 726 def list_attestors request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1::ListAttestorsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_attestors..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_attestors.timeout, metadata: , retry_policy: @config.rpcs.list_attestors.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.list_attestors request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @binauthz_management_service_stub, :list_attestors, "attestors", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
228 229 230 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 228 def logger @binauthz_management_service_stub.logger end |
#universe_domain ⇒ String
The effective universe domain
145 146 147 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 145 def universe_domain @binauthz_management_service_stub.universe_domain end |
#update_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor #update_attestor(attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Attestor
633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 633 def update_attestor request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1::UpdateAttestorRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_attestor..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_attestor.timeout, metadata: , retry_policy: @config.rpcs.update_attestor.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.update_attestor request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#update_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Policy #update_policy(policy: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1::Policy
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 |
# File 'lib/google/cloud/binary_authorization/v1/binauthz_management_service/rest/client.rb', line 375 def update_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1::UpdatePolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_policy..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.update_policy.timeout, metadata: , retry_policy: @config.rpcs.update_policy.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.update_policy request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |