Module: Google::Cloud::BinaryAuthorization::V1::PkixPublicKey::SignatureAlgorithm

Defined in:
proto_docs/google/cloud/binaryauthorization/v1/resources.rb

Overview

Represents a signature algorithm and other information necessary to verify signatures with a given public key. This is based primarily on the public key types supported by Tink's PemKeyType, which is in turn based on KMS's supported signing algorithms. In the future, Binary Authorization might support additional public key types independently of Tink and/or KMS.

Constant Summary collapse

SIGNATURE_ALGORITHM_UNSPECIFIED =

Not specified.

0
RSA_PSS_2048_SHA256 =

RSASSA-PSS 2048 bit key with a SHA256 digest.

1
RSA_SIGN_PSS_2048_SHA256 =

RSASSA-PSS 2048 bit key with a SHA256 digest.

1
RSA_PSS_3072_SHA256 =

RSASSA-PSS 3072 bit key with a SHA256 digest.

2
RSA_SIGN_PSS_3072_SHA256 =

RSASSA-PSS 3072 bit key with a SHA256 digest.

2
RSA_PSS_4096_SHA256 =

RSASSA-PSS 4096 bit key with a SHA256 digest.

3
RSA_SIGN_PSS_4096_SHA256 =

RSASSA-PSS 4096 bit key with a SHA256 digest.

3
RSA_PSS_4096_SHA512 =

RSASSA-PSS 4096 bit key with a SHA512 digest.

4
RSA_SIGN_PSS_4096_SHA512 =

RSASSA-PSS 4096 bit key with a SHA512 digest.

4
RSA_SIGN_PKCS1_2048_SHA256 =

RSASSA-PKCS1-v1_5 with a 2048 bit key and a SHA256 digest.

5
RSA_SIGN_PKCS1_3072_SHA256 =

RSASSA-PKCS1-v1_5 with a 3072 bit key and a SHA256 digest.

6
RSA_SIGN_PKCS1_4096_SHA256 =

RSASSA-PKCS1-v1_5 with a 4096 bit key and a SHA256 digest.

7
RSA_SIGN_PKCS1_4096_SHA512 =

RSASSA-PKCS1-v1_5 with a 4096 bit key and a SHA512 digest.

8
ECDSA_P256_SHA256 =

ECDSA on the NIST P-256 curve with a SHA256 digest.

9
EC_SIGN_P256_SHA256 =

ECDSA on the NIST P-256 curve with a SHA256 digest.

9
ECDSA_P384_SHA384 =

ECDSA on the NIST P-384 curve with a SHA384 digest.

10
EC_SIGN_P384_SHA384 =

ECDSA on the NIST P-384 curve with a SHA384 digest.

10
ECDSA_P521_SHA512 =

ECDSA on the NIST P-521 curve with a SHA512 digest.

11
EC_SIGN_P521_SHA512 =

ECDSA on the NIST P-521 curve with a SHA512 digest.

11
ML_DSA_65 =

ML-DSA-65 Post-Quantum Cryptography signature algorithm.

13