Class: Google::Cloud::BinaryAuthorization::V1::ValidateAttestationOccurrenceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/binaryauthorization/v1/service.rb

Overview

Instance Attribute Summary collapse

Instance Attribute Details

#attestation::Grafeas::V1::AttestationOccurrence

Returns Required. An AttestationOccurrence to be checked that it can be verified by the Attestor. It does not have to be an existing entity in Container Analysis. It must otherwise be a valid AttestationOccurrence.

Returns:



179
180
181
182
# File 'proto_docs/google/cloud/binaryauthorization/v1/service.rb', line 179

class ValidateAttestationOccurrenceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#attestor::String

Returns Required. The resource name of the Attestor of the [occurrence][grafeas.v1.Occurrence], in the format projects/*/attestors/*.

Returns:

  • (::String)

    Required. The resource name of the Attestor of the [occurrence][grafeas.v1.Occurrence], in the format projects/*/attestors/*.



179
180
181
182
# File 'proto_docs/google/cloud/binaryauthorization/v1/service.rb', line 179

class ValidateAttestationOccurrenceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#occurrence_note::String

Returns Required. The resource name of the [Note][grafeas.v1.Note] to which the containing [Occurrence][grafeas.v1.Occurrence] is associated.

Returns:

  • (::String)

    Required. The resource name of the [Note][grafeas.v1.Note] to which the containing [Occurrence][grafeas.v1.Occurrence] is associated.



179
180
181
182
# File 'proto_docs/google/cloud/binaryauthorization/v1/service.rb', line 179

class ValidateAttestationOccurrenceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#occurrence_resource_uri::String

Returns Required. The URI of the artifact (e.g. container image) that is the subject of the containing [Occurrence][grafeas.v1.Occurrence].

Returns:

  • (::String)

    Required. The URI of the artifact (e.g. container image) that is the subject of the containing [Occurrence][grafeas.v1.Occurrence].



179
180
181
182
# File 'proto_docs/google/cloud/binaryauthorization/v1/service.rb', line 179

class ValidateAttestationOccurrenceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end