Class: Grafeas::V1::BaseImage

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/common.rb

Overview

BaseImage describes a base image of a container image.

Instance Attribute Summary collapse

Instance Attribute Details

#layer_count::Integer

Returns The number of layers that the base image is composed of.

Returns:

  • (::Integer)

    The number of layers that the base image is composed of.



135
136
137
138
# File 'proto_docs/grafeas/v1/common.rb', line 135

class BaseImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns The name of the base image.

Returns:

  • (::String)

    The name of the base image.



135
136
137
138
# File 'proto_docs/grafeas/v1/common.rb', line 135

class BaseImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#repository::String

Returns The repository name in which the base image is from.

Returns:

  • (::String)

    The repository name in which the base image is from.



135
136
137
138
# File 'proto_docs/grafeas/v1/common.rb', line 135

class BaseImage
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end