Class: Grafeas::V1::LayerDetails

Inherits:
Object
  • Object
show all
Extended by:
Google::Protobuf::MessageExts::ClassMethods
Includes:
Google::Protobuf::MessageExts
Defined in:
proto_docs/grafeas/v1/common.rb

Overview

Details about the layer a package was found in.

Instance Attribute Summary collapse

Instance Attribute Details

#base_images::Array<::Grafeas::V1::BaseImage>

Returns The base images the layer is found within.

Returns:



161
162
163
164
# File 'proto_docs/grafeas/v1/common.rb', line 161

class LayerDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#chain_id::String

Returns The layer chain ID (sha256 hash) of the layer in the container image. https://github.com/opencontainers/image-spec/blob/main/config.md#layer-chainid.

Returns:



161
162
163
164
# File 'proto_docs/grafeas/v1/common.rb', line 161

class LayerDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#command::String

Returns The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built.

Returns:

  • (::String)

    The layer build command that was used to build the layer. This may not be found in all layers depending on how the container image is built.



161
162
163
164
# File 'proto_docs/grafeas/v1/common.rb', line 161

class LayerDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#diff_id::String

Returns The diff ID (typically a sha256 hash) of the layer in the container image.

Returns:

  • (::String)

    The diff ID (typically a sha256 hash) of the layer in the container image.



161
162
163
164
# File 'proto_docs/grafeas/v1/common.rb', line 161

class LayerDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#index::Integer

Returns The index of the layer in the container image.

Returns:

  • (::Integer)

    The index of the layer in the container image.



161
162
163
164
# File 'proto_docs/grafeas/v1/common.rb', line 161

class LayerDetails
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end