Class: Google::Cloud::BinaryAuthorization::V1::ValidateAttestationOccurrenceResponse
- Inherits:
-
Object
- Object
- Google::Cloud::BinaryAuthorization::V1::ValidateAttestationOccurrenceResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/binaryauthorization/v1/service.rb
Overview
Response message for ValidationHelperV1.ValidateAttestationOccurrence.
Defined Under Namespace
Modules: Result
Instance Attribute Summary collapse
-
#denial_reason ⇒ ::String
The reason for denial if the Attestation couldn't be validated.
-
#result ⇒ ::Google::Cloud::BinaryAuthorization::V1::ValidateAttestationOccurrenceResponse::Result
The result of the Attestation validation.
Instance Attribute Details
#denial_reason ⇒ ::String
Returns The reason for denial if the Attestation couldn't be validated.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'proto_docs/google/cloud/binaryauthorization/v1/service.rb', line 192 class ValidateAttestationOccurrenceResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The enum returned in the `result` field. module Result # Unspecified. RESULT_UNSPECIFIED = 0 # The Attestation was able to verified by the Attestor. VERIFIED = 1 # The Attestation was not able to verified by the Attestor. ATTESTATION_NOT_VERIFIABLE = 2 end end |
#result ⇒ ::Google::Cloud::BinaryAuthorization::V1::ValidateAttestationOccurrenceResponse::Result
Returns The result of the Attestation validation.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'proto_docs/google/cloud/binaryauthorization/v1/service.rb', line 192 class ValidateAttestationOccurrenceResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The enum returned in the `result` field. module Result # Unspecified. RESULT_UNSPECIFIED = 0 # The Attestation was able to verified by the Attestor. VERIFIED = 1 # The Attestation was not able to verified by the Attestor. ATTESTATION_NOT_VERIFIABLE = 2 end end |