Class: Grafeas::V1::FileLocation
- Inherits:
-
Object
- Object
- Grafeas::V1::FileLocation
- Extended by:
- Google::Protobuf::MessageExts::ClassMethods
- Includes:
- Google::Protobuf::MessageExts
- Defined in:
- proto_docs/grafeas/v1/common.rb
Overview
Indicates the location at which a package was found.
Instance Attribute Summary collapse
-
#file_path ⇒ ::String
For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
-
#layer_details ⇒ ::Grafeas::V1::LayerDetails
Each package found in a file should have its own layer metadata (that is, information from the origin layer of the package).
Instance Attribute Details
#file_path ⇒ ::String
Returns For jars that are contained inside .war files, this filepath can indicate the path to war file combined with the path to jar file.
120 121 122 123 |
# File 'proto_docs/grafeas/v1/common.rb', line 120 class FileLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#layer_details ⇒ ::Grafeas::V1::LayerDetails
Returns Each package found in a file should have its own layer metadata (that is, information from the origin layer of the package).
120 121 122 123 |
# File 'proto_docs/grafeas/v1/common.rb', line 120 class FileLocation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |